<?php

declare(strict_types=1);

namespace Webmozart\Assert\Tests;

// The filename must be different from the class name to be ignored by composer PSR-4 autoloading rules
enum DummyEnum
{
    case CaseName;
}
